pub unsafe extern "C" fn SteamAPI_ManualDispatch_Init()Expand description
Inform the API that you wish to use manual event dispatch. This must be called after SteamAPI_Init, but before you use any of the other manual dispatch functions below.
pub unsafe extern "C" fn SteamAPI_ManualDispatch_Init()Inform the API that you wish to use manual event dispatch. This must be called after SteamAPI_Init, but before you use any of the other manual dispatch functions below.