#[repr(C)]pub struct SteamNetAuthenticationStatus_t {
pub m_eAvail: ESteamNetworkingAvailability,
pub m_debugMsg: [c_char; 256],
}Expand description
A struct used to describe our readiness to participate in authenticated, encrypted communication. In order to do this we need:
- The list of trusted CA certificates that might be relevant for this app.
- A valid certificate issued by a CA.
This callback is posted whenever the state of our readiness changes.
Fields
m_eAvail: ESteamNetworkingAvailabilityStatus
m_debugMsg: [c_char; 256]Non-localized English language status. For diagnostic/debugging purposes only.